summary_map: Quantitative summary of a unique categorical raster

View source: R/generalfunctions.R

summary_mapR Documentation

Quantitative summary of a unique categorical raster

Description

This function presents a summary with the pixel quantity of each category present in a categorical raster.

Usage

summary_map(path)

Arguments

path

The path for the raster to be analysed, if path is a multilayer raster only the first RasterLayer will be analysed.

Value

A table containing in columns the pixel counts for each pixel value

Examples


url <- "https://zenodo.org/record/3685230/files/SaoLourencoBasin.rda?download=1"
if (OpenLand:::.openland_try_download_and_load_rda(url,
  object = "SaoLourencoBasin", timeout = 10,
  cache = FALSE
)) {
  summary_map(SaoLourencoBasin[[1]])
}



OpenLand documentation built on July 10, 2026, 9:06 a.m.