View source: R/generalfunctions.R
| acc_changes | R Documentation |
This function calculates the number of times a pixel has changed during the analysed period. It returns a raster with the number of changes as pixel value and a table containing the areal percentage of every pixel value (number of changes).
acc_changes(path)
path |
The path for the Raster* directory or list of Raster* to be analysed. |
Two objects, a RasterLayer and a table.
url <- "https://zenodo.org/record/3685230/files/SaoLourencoBasin.rda?download=1"
if (OpenLand:::.openland_try_download_and_load_rda(url,
object = "SaoLourencoBasin", timeout = 10,
cache = FALSE
)) {
acc_changes(SaoLourencoBasin)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.