View source: R/generalfunctions.R
| summary_map | R Documentation |
This function presents a summary with the pixel quantity of each category present in a categorical raster.
summary_map(path)
path |
The path for the raster to be analysed, if path is a multilayer raster only the first RasterLayer will be analysed. |
A table containing in columns the pixel counts for each pixel value
url <- "https://zenodo.org/record/3685230/files/SaoLourencoBasin.rda?download=1"
if (OpenLand:::.openland_try_download_and_load_rda(url,
object = "SaoLourencoBasin", timeout = 10,
cache = FALSE
)) {
summary_map(SaoLourencoBasin[[1]])
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.